@@ -203,9 +203,10 @@ void app_normal_screen (Application *app) {
 
 void app_store_save_directory (Application *app, gchar *path) {
     if (path && path[0]) {
+        char *dir;
         if (app->save_folder)
             g_free (app->save_folder);
-        char *dir = dirname (path);
+        dir = dirname (path);
         app->save_folder = (gchar *) g_malloc (strlen (dir) + 2);
         sprintf (app->save_folder, "%s/", dir);
         g_free (dir);
@@ -232,34 +233,14 @@ static void callback_file_go (GtkButton *button, Application *app) {
     }
 }
 
-static void callback_file_save_as (GtkButton * button, Application * app) {
-    gchar *filename = NULL;
-    filename = app_file_chooser (app, app->save_folder, GTK_FILE_CHOOSER_ACTION_SAVE);
-    if (filename) {
-        gchar * info;
-        if (saveFile (app->control, filename)) {
-            info = g_strdup_printf ("Saved as %s", filename);
-            gtk_window_set_title (app->window, filename);
-            app_insert_location (app, filename);
-        } else
-            info = g_strdup_printf ("Saving as %s failed (%s)", filename, strerror (errno));
-        hildon_banner_show_information (GTK_WIDGET (app->window), NULL, info);
-        g_free (info);
-        app_store_save_directory (app, filename);
-    }
+static void callback_file_export_m3u (GtkButton *button, Application *app) {
+    (void) button;
+    saveFile (app, false);
 }
 
-static void callback_file_save (GtkButton * button, Application * app) {
-    const char * fn = saveFile (app->control, NULL);
-    gchar *info;
-    if (fn && fn [0]) {
-        info = g_strdup_printf ("Saved as %s", fn);
-    } else {
-        info = g_strdup_printf ("Saving failed (%s)", strerror (errno));
-        hildon_banner_show_information (GTK_WIDGET (app->window), NULL, info);
-        callback_file_save_as (0L, app);
-    }
-    g_free (info);
+static void callback_file_export_xml (GtkButton *button, Application *app) {
+    (void) button;
+    saveFile (app, true);
 }
 
 static void callback_file_new (GtkButton * button, Application * app) {
@@ -422,8 +403,8 @@ static void create_menu (Application * app) {
     GtkMenu *main_menu;
     GtkWidget *item_new;
     GtkWidget *item_open;
-    GtkWidget *item_save;
-    GtkWidget *item_save_as;
+    GtkWidget *item_export_xml;
+    GtkWidget *item_export_m3u;
     GtkWidget *menu_playlist;
     GtkWidget *menu_generators;
     GtkWidget *menu_players;
@@ -444,8 +425,8 @@ static void create_menu (Application * app) {
     /* Create menu items */
     item_new = gtk_menu_item_new_with_label ("New");
     item_open = gtk_menu_item_new_with_label ("Open");
-    item_save = gtk_menu_item_new_with_label ("Save");
-    item_save_as = gtk_menu_item_new_with_label ("Save As");
+    item_export_xml = gtk_menu_item_new_with_label ("Export XML");
+    item_export_m3u = gtk_menu_item_new_with_label ("Export m3u");
     /* item_check = gtk_check_menu_item_new_with_label ("Check");*/
     item_playlist = gtk_menu_item_new_with_label ("Playlist");
     item_playlist_show = gtk_check_menu_item_new_with_label ("Show");
@@ -470,8 +451,7 @@ static void create_menu (Application * app) {
     /* Add menu items to right menus */
     gtk_menu_append (main_menu, item_new);
     gtk_menu_append (main_menu, item_open);
-    gtk_menu_append (main_menu, item_save);
-    gtk_menu_append (main_menu, item_save_as);
+    gtk_menu_append (main_menu, item_playlist_generators);
     gtk_menu_append (main_menu, item_playlist);
     gtk_menu_append (main_menu, item_players);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_copy);
@@ -479,7 +459,8 @@ static void create_menu (Application * app) {
     gtk_menu_append (menu_playlist, app->menu_item_playlist_paste_in_group);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_cut);
     gtk_menu_append (menu_playlist, gtk_separator_menu_item_new ());
-    gtk_menu_append (menu_playlist, item_playlist_generators);
+    gtk_menu_append (menu_playlist, item_export_xml);
+    gtk_menu_append (menu_playlist, item_export_m3u);
     gtk_menu_append (menu_playlist, gtk_separator_menu_item_new ());
     gtk_menu_append (menu_playlist, app->menu_item_playlist_title);
     gtk_menu_append (menu_playlist, app->menu_item_playlist_showall);
@@ -503,10 +484,10 @@ static void create_menu (Application * app) {
         GTK_SIGNAL_FUNC (cb_mainview_close), app);
     g_signal_connect (G_OBJECT (item_open), "activate",
         GTK_SIGNAL_FUNC (callback_file_open), app);
-    g_signal_connect (G_OBJECT (item_save), "activate",
-        GTK_SIGNAL_FUNC (callback_file_save), app);
-    g_signal_connect (G_OBJECT (item_save_as), "activate",
-        GTK_SIGNAL_FUNC (callback_file_save_as), app);
+    g_signal_connect (G_OBJECT (item_export_xml), "activate",
+        GTK_SIGNAL_FUNC (callback_file_export_xml), app);
+    g_signal_connect (G_OBJECT (item_export_m3u), "activate",
+        GTK_SIGNAL_FUNC (callback_file_export_m3u), app);
     g_signal_connect (G_OBJECT (item_playlist), "activate",
         GTK_SIGNAL_FUNC (cb_playlistMenuActivate), app);
     g_signal_connect (G_OBJECT (app->menu_item_playlist_copy), "activate",
