@@ -50,8 +50,10 @@ void FileDocument::readFromFile (const String & fn) {
     if (file.exists ()) {
         file.open (IO_ReadOnly);
         ByteArray data = file.readAll ();
-        if (data.size ())
-            insertBefore (String (data.data (), data.size ()), NULL);
+        if (data.size ()) {
+            TextStream xml (&data);
+            readXML (this, xml, String (), false);
+        }
     }
     load_tree_version = m_tree_version;
 }
@@ -502,10 +504,9 @@ void Generator::activate () {
         } else {
             String cmdline (input + " | " + process);
             message (MsgInfoString, &cmdline);
-            if (!media_info)
-                media_info = new MediaInfo (this, ActorAgent::Data);
             state = state_activated;
-            media_info->wget (input);
+            input_job = asyncGet (this, input);
+            input_job->start ();
         }
     }
 }
@@ -515,15 +516,11 @@ void Generator::begin () {
         unix_process = new UnixProcess (
                 this, UnixProcess::StdIn | UnixProcess::StdOut);
     String info;
-    if (media_info)
-        info = String ("Input data ") +
-            String::number (media_info->rawData ().size () / 1024.0) + "kb | ";
     info += process;
     message (MsgInfoString, &info);
     if (unix_process->start (m_control->data_dir, process)) {
         state = state_began;
-        write_pos = 0;
-        if (media_info && media_info->rawData ().size ())
+        if (buffer)
             unix_process->pollStdIn (true);
     } else {
         String err ("Couldn't start process");
@@ -533,29 +530,22 @@ void Generator::begin () {
 }
 
 void Generator::deactivate () {
-    if (unix_process)
+    if (unix_process) {
         unix_process->stop ();
-    delete unix_process;
-    unix_process = NULL;
+        delete unix_process;
+        unix_process = NULL;
+    }
+    if (input_job) {
+        input_job->kill ();
+        input_job = NULL;
+    }
     delete data;
     data = NULL;
+    delete buffer;
+    buffer = NULL;
     FileDocument::deactivate ();
 }
 
-void Generator::message (KMPlayer::MessageType msg, void *content) {
-    if (MsgMediaReady == msg) {
-        if (!media_info->rawData ().size ()) {
-            String err ("No input data received");
-            message (MsgInfoString, &err);
-            deactivate ();
-        } else {
-            begin ();
-        }
-    } else {
-        FileDocument::message (msg, content);
-    }
-}
-
 void Generator::readEvent (UnixProcess *) {
     char buf[1024];
     int nr;
@@ -569,11 +559,10 @@ void Generator::readEvent (UnixProcess *) {
     } while (nr > 0);
     if (unix_process->eof) {
         unix_process->closeStdOut ();
-        String s = data->release ();
-        if (!s.isEmpty ()) {
+        if (!data->isEmpty ()) {
             Playlist *pl = new Playlist (m_control->m_app, m_control, true);
             NodePtr n = pl;
-            pl->insertBefore (s, NULL);
+            readXML (pl, *data, String (), false);
             pl->title = title;
             message (MsgInfoString, NULL);
             m_control->openDocument (n, NULL);
@@ -588,20 +577,29 @@ void Generator::readEvent (UnixProcess *) {
 }
 
 void Generator::writeEvent (UnixProcess *) {
-    if (media_info) {
-        ByteArray &ba = media_info->rawData ();
-        const gchar *start = ba.data () + write_pos;
+    if (buffer) {
+        const gchar *start = buffer->data ();
         const gchar *end;
-        int wmax = ba.size () - write_pos;
+        int wmax = buffer->size ();
         int wcount = wmax;
         if (!g_utf8_validate (start, wmax, &end))
             wcount = end - start;
         int nr = unix_process->writeStdIn (start, wcount);
-        write_pos += nr;
         if (nr == wcount && wcount < wmax)
-            write_pos++; //skip
-        if (write_pos < ba.size ())
+            nr++; //skip
+        if (nr < buffer->size ()) {
+            if (nr) {
+                int new_size = buffer->size () - nr;
+                memmove (buffer->data(), buffer->data() + nr, new_size);
+                buffer->resize (new_size);
+            }
             return;
+        }
+        buffer->resize (0);
+        if (input_job) {
+            unix_process->pollStdIn (false);
+            return;
+        }
     }
     unix_process->closeStdIn ();
     message (MsgInfoString, &process);
@@ -613,6 +611,33 @@ void Generator::processExited (UnixProcess *) {
         readEvent (NULL);
 }
 
+void Generator::jobData (IOJob *job, ByteArray &data) {
+    if (job->error ()) {
+        job->kill (false);
+    } else if (data.size ()) {
+        if (!buffer) {
+            buffer = new ByteArray (data);
+            begin ();
+        } else {
+            int p = buffer->size ();
+            buffer->resize (p + data.size ());
+            memcpy (buffer->data () + p, data.data (), data.size ());
+            unix_process->pollStdIn (true);
+        }
+    }
+}
+
+void Generator::jobResult (IOJob *) {
+    input_job = NULL;
+    if (!buffer) {
+        String err ("No input data received");
+        message (MsgInfoString, &err);
+        deactivate ();
+    } else if (unix_process && !buffer->size ()) {
+        unix_process->closeStdIn ();
+    }
+}
+
 struct GeneratorTag {
     const char *tag;
     short id;
