@@ -57,7 +57,6 @@ KDE_NO_EXPORT void RP::Imfl::closed () {
 }
 
 KDE_NO_EXPORT void RP::Imfl::defer () {
-    debugLog () << "RP::Imfl::defer " << endl;
     setState (state_deferred);
     for (Node *n = firstChild (); n; n = n->nextSibling ())
         if (n->id == RP::id_node_image && !n->active ())
@@ -65,7 +64,6 @@ KDE_NO_EXPORT void RP::Imfl::defer () {
 }
 
 KDE_NO_EXPORT void RP::Imfl::activate () {
-    debugLog () << "RP::Imfl::activate " << endl;
     resolved = true;
     setState (state_activated);
     int timings_count = 0;
@@ -93,7 +91,6 @@ KDE_NO_EXPORT void RP::Imfl::activate () {
 }
 
 KDE_NO_EXPORT void RP::Imfl::finish () {
-    debugLog () << "RP::Imfl::finish " << endl;
     Mrl::finish ();
     if (duration_timer) {
         document ()->cancelPosting (duration_timer);
