@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2005-2006 Koos Vriezen <koos.vriezen@gmail.com>
+ * Copyright (C) 2005 Koos Vriezen <koos.vriezen@xs4all.nl>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,8 +21,6 @@
 #ifndef _KMPLAYER_RSS_H_
 #define _KMPLAYER_RSS_H_
 
-#include <qstring.h>
-
 #include "kmplayerplaylist.h"
 
 namespace KMPlayer {
@@ -35,41 +33,39 @@ const short id_node_item = 202;
 const short id_node_title = 203;
 const short id_node_description = 204;
 const short id_node_enclosure = 205;
+const short id_node_category = 206;
+const short id_node_ignored = 207;
 
 /**
  * '<RSS>' tag
  */
-class Rss : public Mrl {
+class KMPLAYER_NO_EXPORT Rss : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Rss (NodePtr & d) : Mrl (d, id_node_rss) {}
-    NodePtr childFromTag (const QString & tag);
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "rss"; }
     bool expose () const { return false; }
 };
-    
-class KMPLAYER_NO_EXPORT Channel : public Mrl {
+
+class KMPLAYER_NO_EXPORT Channel : public Title {
 public:
-    KDE_NO_CDTOR_EXPORT Channel (NodePtr & d) : Mrl (d, id_node_channel) {}
-    NodePtr childFromTag (const QString & tag);
+    KDE_NO_CDTOR_EXPORT Channel (NodePtr & d) : Title (d, id_node_channel) {}
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "channel"; }
     PlayType playType () { return play_type_none; }
     void closed ();
     bool expose () const;
 };
 
-class KMPLAYER_NO_EXPORT Item : public Mrl {
+class KMPLAYER_NO_EXPORT Item : public Title {
 public:
-    KDE_NO_CDTOR_EXPORT Item (NodePtr & d) : Mrl (d, id_node_item) {}
-    NodePtr childFromTag (const QString & tag);
+    KDE_NO_CDTOR_EXPORT Item (NodePtr & d)
+        : Title (d, id_node_item), summary_added (false) {}
+    Node *childFromTag (const String & tag);
+    String description () const;
     KDE_NO_EXPORT const char * nodeName () const { return "item"; }
-    PlayType playType () { return cached_play_type; }
-    Mrl * linkNode ();
     void closed ();
-    void activate ();
-    void deactivate ();
-    bool handleEvent (EventPtr event);
-    NodePtrW enclosure;
-    TimerInfoPtrW timer;
+    bool summary_added;
 };
 
 class KMPLAYER_NO_EXPORT Enclosure : public Mrl {
@@ -77,7 +73,9 @@ public:
     KDE_NO_CDTOR_EXPORT Enclosure(NodePtr &d) : Mrl(d, id_node_enclosure) {}
     KDE_NO_EXPORT const char * nodeName () const { return "enclosure"; }
     void closed ();
-    bool expose () const { return false; }
+    void activate ();
+    void deactivate ();
+    String description;
 };
 
 } //namespace RSS
