@@ -134,9 +134,7 @@ public:
         DurationItem *next;
     } durations [(const int) DurTimeLast];
     void setDuration ();
-    bool started () const {
-        return timingstate == timings_started || timingstate == timings_paused;
-    }
+    bool started () const;
     bool active () const {
         return timingstate >= timings_started && timingstate != timings_stopped;
     }
@@ -336,10 +334,6 @@ public:
     ShowBackground show_background;
     Fit fit;
     ConnectionList m_AttachedMediaTypes;   // active attached mediatypes
-    /**
-     * boolean for check if pointerEntered/pointerLeft should be called by View
-     */
-    bool has_mouse;
 protected:
     RegionBase (NodePtr & d, short id);
     PostponePtr postpone_lock;               // pause while loading bg image
@@ -574,7 +568,6 @@ public:
     void deactivate ();
     KDE_NO_EXPORT bool expose () const { return false; }
     void parseParam (const TrieString & name, const String & value);
-    ConnectionLink mediatype_activated;
     ConnectionLink mediatype_attach;
     String href;
     String target;
@@ -659,19 +652,15 @@ public:
     Command *trans_out_timer;
     enum { sens_opaque, sens_transparent, sens_percentage } sensitivity;
     bool trans_out_active;
-    bool has_mouse;
 
 protected:
     virtual void clipStart ();
     virtual void clipStop ();
 
     MouseListeners mouse_listeners;
-    ConnectionList m_MediaAttached;        // mouse entered
+    ConnectionList m_MediaAttached;
     ConnectionList m_TransformedIn;        // transIn ready
     ConnectionLink region_paint;           // attached region needs painting
-    ConnectionLink region_mouse_enter;     // attached region has mouse entered
-    ConnectionLink region_mouse_leave;     // attached region has mouse left
-    ConnectionLink region_mouse_click;     // attached region is clicked
     ConnectionLink region_attach;          // attached to region
     ConnectionLink document_postponed;     // pause audio/video accordantly
     PostponePtr postpone_lock;
@@ -746,6 +735,7 @@ public:
     SurfacePtrW text_surface;
     NodePtrW region_node;
     ConnectionLink region_attach;
+    ConnectionList media_attached;
     MouseListeners mouse_listeners;
     Runtime *runtime;
 };
