@@ -180,7 +180,6 @@ void Control::init () {
         GConfEntry *entry = (GConfEntry *)elm->data;
         GConfValue *value = gconf_entry_get_value (entry);
         const char *str = gconf_value_get_string (value);
-        debugLog() << entry->key << "=" << str << endl;
         if (str && *str) {
             Playlist *expl = new Playlist (m_app, 0L);
             extra_playlists.append (expl);
@@ -296,7 +295,6 @@ void Control::play () {
         else
             playlist_data->document->defer ();   // pause
     } else {
-        debugLog () << "play" << endl;
         //gtk_paned_set_position (m_app->vsplit_view, VSPLIT);
         //gtk_container_resize_children (GTK_CONTAINER (m_app->vsplit_view));
         if (!applyBackRequest () && playlist_data->document) {
@@ -306,7 +304,6 @@ void Control::play () {
 }
 
 void Control::stop (bool keep_fullscreen) {
-    debugLog () << "stop" << endl;
     setLoading (100); // no pogress bar
     back_request = 0L;
     if (playlist_data->document &&
@@ -654,7 +651,6 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
     } else if ((ns == Node::state_deferred ||
                 (os == Node::state_deferred && ns > Node::state_deferred)) &&
             n == playlist_data->document) {
-    debugLog () << "doc state " << stateDesc [int (os)] << " changed to " << stateDesc [int (ns)] << endl;
         if ((ns == Node::state_deferred &&
                     m_process->state() != Process::Paused) ||
                 (ns > Node::state_deferred &&
@@ -707,7 +703,6 @@ void Control::updateViewAreaSizes () {
             y += y1;
         }
     }
-    debugLog () << "updateViewAreaSizes " << x << ", " << y << " " << video_rect.width () << "x" << video_rect.height () << endl;
     m_process->setVideoWindow (x, y,
             video_rect.width (), video_rect.height ());
 }
@@ -729,10 +724,12 @@ static const char * statemap [] = {
 };
 
 void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
+    Mrl *mrl = p->mrl ();
+    NodePtrW guard = mrl; // p->mrl is weak, needs check
     debugLog () << "Process stateChanged " << statemap [(int)os] << " -> " << statemap [(int)ns] << endl;
     if (!m_process) // destructing
         return;
-    if (!p->mrl () && ns > Process::Ready) {
+    if (!mrl && ns > Process::Ready) {
         p->stop (); // reschedule to the NotRunning state
     } else if (ns == Process::NotRunning) {
         if (p == m_process) {
@@ -741,10 +738,10 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
                 stop (); // this should not happen
             }
             app_update_screen_blanking (m_app);
-            if (p == downloader &&
+            if (p == downloader && os > Process::Ready && guard &&
                     !((Downloader *) downloader)->saved_file.isEmpty ())
                 addRecent (((Downloader *) downloader)->saved_file,
-                        p->mrl ()->caption ());
+                        mrl->caption ());
         }
         // else process changed
         if (!playlist_data->edit_mode)
@@ -755,9 +752,7 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
             setLength (0);
             setPosition (0);
             VIEWAREA(m_app)->setAspect (0.0);
-            NodePtr node = p->mrl (); // p->mrl is weak, needs check
-            Mrl * mrl = node ? node->mrl () : 0L;
-            if (mrl && !applyBackRequest () &&  // if cause is no jump
+            if (guard && !applyBackRequest () &&  // if cause is no jump
                     mrl->active ()) {           // if cause is eof
                 mrl->message (MsgMediaFinished);// set node to finished
                 if (back_request)            // overlapping audio/video in SMIL
@@ -766,14 +761,13 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
         } else
             g_timeout_add (0, playCurrentSchedule, static_cast <void *> (this));
     } else if (ns == Process::Buffering) {
-        Mrl *mrl = p->mrl ();
         if (mrl->view_mode != Mrl::SingleMode) {
             AudioVideoActor *actor = mrl->media_info
                 ? static_cast <AudioVideoActor *> (mrl->media_info->media)
                 : NULL;
             if (actor)
                 actor->ignore_pause = true;
-            p->mrl ()->defer ();
+            mrl->defer ();
             if (actor)
                 actor->ignore_pause = false;
         }
@@ -787,7 +781,6 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
         else
             playlist_data->document->defer ();
     } else if (ns == Process::Playing) {
-        Mrl *mrl = p->mrl ()->mrl ();
         mrl->audio_only |= !p->hasVideo ();
         if (mrl->state == Element::state_deferred) {
             AudioVideoActor *actor = mrl->media_info
@@ -795,7 +788,7 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
                 : NULL;
             if (actor)
                 actor->ignore_pause = true;
-            p->mrl ()->undefer ();
+            mrl->undefer ();
             if (actor)
                 actor->ignore_pause = false;
         }
@@ -916,7 +909,6 @@ void Control::setLength (int len) {
 }
 
 void Control::setAspect (float aspect) {
-    debugLog () << "Control::setAspect " << aspect << endl;
     VIEWAREA(m_app)->setAspect (aspect);
     updateViewAreaSizes ();
 }
@@ -1187,14 +1179,12 @@ void newFile (Application * app) {
 
 gboolean cb_mainview_delete (GtkObject *, GdkEvent *, Application *app) {
     CONTROL(app)->deinit ();
-    debugLog () << "delete" << endl;
     gtk_main_quit ();
     return false;
 }
 
 void cb_mainview_close (GtkObject *, Application *app) {
     CONTROL(app)->deinit ();
-    debugLog () << "close" << endl;
     gtk_main_quit ();
 }
 
@@ -1314,7 +1304,6 @@ locationbarGainFocus (GtkWidget *, GdkEventFocus *, Application * app) {
         gtk_widget_hide (GTK_WIDGET (gtk_toolbar_get_nth_item (GTK_TOOLBAR (app->main_toolbar), i)));
     app_set_playing (app, app->playing);
     if (!locationbar_initialized) {
-        KMPlayer::debugLog() << "locationbar_initializing" << KMPlayer::endl;
         const char * defs[6] = {
             "http://www.cwi.nl/SMIL/EUROshow/EUROshowB.smi",
             "http://homepages.cwi.nl/~media/SMIL/fiets/fiets.smil",
@@ -1361,7 +1350,6 @@ void save_locationbar (Application *app) {
         gtk_tree_model_get_value (model, &iterator, 0, &value);
         KMPlayer::String val (g_value_get_string (&value));
         g_value_unset (&value);
-        KMPlayer::debugLog() << val << " " << idx << KMPlayer::endl;
         if (!val.isEmpty ())
             config->writeEntry (cfg_pfx + KMPlayer::String::number(idx++), val);
     }
@@ -1386,14 +1374,12 @@ static void generatorActivate (GtkMenuItem *item, Control *ctrl) {
 static void getGenerators (GtkWidget *menu, Control *ctrl, const String &dir) {
     GDir *gdir = g_dir_open ((const char *) dir, 0, NULL);
     if (gdir) {
-        debugLog() << dir << endl;
         const gchar *file = g_dir_read_name (gdir);
         while (file) {
             Generator *gen = new Generator (ctrl);
             NodePtr doc = gen;
             gen->readFromFile (dir + Char ('/') + file);
             Node *n = gen->firstChild ();
-            debugLog() << file << " " << n->nodeName() << endl;
             if (n && n->isElementNode ()) {
                 String name = static_cast <Element *> (n)->getAttribute (
                         StringPool::attr_name);
@@ -1423,7 +1409,6 @@ void generatorMenuActivate (GtkMenuItem *item, Application *app) {
     getGenerators (menu, ctrl, "/usr/share/applications/kmplayer/generators");
     getGenerators (menu, ctrl, ctrl->data_dir + "/generators");
     gtk_widget_show_all (menu);
-    debugLog () << "Generator menu " << menu << endl;
 }
 /*
  * TODO
