@@ -79,7 +79,7 @@ public:
      * PlayListNotify implementation
      */
     ActorAgent *actorAgent () const;
-    bool requestPlayURL (NodePtr mrl);
+    bool requestPlayURL (Mrl *mrl);
     bool setCurrent (NodePtr);
     bool applyBackRequest();
     void stateElementChanged (Node * n, Node::State os, Node::State ns);
@@ -146,7 +146,8 @@ class MAEMO_NO_EXPORT SourceDocument : public Document {
 public:
     SourceDocument (Control *c, const String &url);
 
-    void *message (MessageType msg, void *data=NULL);
+    void message (MessageType msg, void *data=NULL);
+    void *role (RoleType msg, void *data=NULL);
 
     Control *m_control;
 };
