@@ -332,7 +332,7 @@ void TreeNode<Node>::removeChild (NodePtr c) {
 
 KDE_NO_EXPORT void Node::insertBefore (const String &xml, Node *b) {
     Node *last = lastChild ();
-    TextStream inxml ((const char *) xml);
+    TextStream inxml (&xml);
     readXML (this, inxml, String(), false);
     if (lastChild () != last) {
         NodePtr n = lastChild ();
@@ -1701,7 +1701,7 @@ void KMPlayer::readXML (NodePtr root, TextStream & in, const String & firstline,
     SimpleSAXParser parser (builder);
     if (!firstline.isEmpty ()) {
         String str (firstline + char_nl);
-        TextStream fl_in (str /*, IO_ReadOnly*/);
+        TextStream fl_in (&str /*, IO_ReadOnly*/);
         parser.parse (fl_in);
     }
     if (!in.atEnd ())
