@@ -447,7 +447,6 @@ void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
     GtkTreeView *treeview = GTK_TREE_VIEW (app->playlist_view);
     GtkTreeIter iter;
     PlayListData * pld = 0L;
-    debugLog() << "tree selection changed" << endl;
     //g_print ("cb_selection_changed %d\n", app->playlist_data->show_all);
     if (gtk_tree_selection_get_selected (selection, 0L, &iter)) {
         GtkTreeModel * model = gtk_tree_view_get_model (treeview);
@@ -507,7 +506,6 @@ void KMPlayer::rowSelected (Application *app) {
     bool expand_collapse = false;
     Node *node = NULL;
 
-    debugLog() << "row selected" << endl;
     if (!gtk_tree_selection_get_selected (sel, 0L, &iter))
         return;
 
