@@ -38,23 +38,26 @@
 using namespace KMPlayer;
 
 KMPLAYER_NO_CDTOR_EXPORT ByteArrayImpl::ByteArrayImpl (const ByteArrayImpl & b)
- : m_data (b.m_size ? (char *) malloc (b.m_size) : 0L),
+ : m_data (b.m_size ? (char *) malloc (b.m_size + 1) : 0L),
    m_size (b.m_size),
    m_capacity (b.m_size),
    data_owner (true) {
-    if (m_size)
+    if (m_size) {
         memcpy (m_data, b.m_data, m_size);
+        m_data[m_size] = 0;
+    }
 }
 
 KMPLAYER_NO_EXPORT void ByteArrayImpl::resize (unsigned ns) {
     if (ns > m_capacity) {
-        char * tmp = (char *) malloc (ns);
+        char * tmp = (char *) malloc (ns + 1);
         if (m_size > 0)
             memcpy (tmp, m_data, m_size);
         m_capacity = m_size = ns;
         if (m_data && data_owner)
             free (m_data);
         m_data = tmp;
+        m_data[ns] = 0;
         data_owner = true;
     } else
         m_size = ns;
@@ -64,11 +67,14 @@ KMPLAYER_NO_EXPORT
 ByteArrayImpl & ByteArrayImpl::operator = (const ByteArrayImpl & b) {
     if (m_data && data_owner)
         free (m_data);
-    m_data = (b.m_size ? (char*) malloc (b.m_size) : 0L);
+    m_data = (b.m_size ? (char*) malloc (b.m_size + 1) : 0L);
     m_size = b.m_size;
     m_capacity = b.m_size;
-    if (m_size)
+    data_owner = true;
+    if (m_size) {
         memcpy (m_data, b.m_data, m_size);
+        m_data[m_size] = 0;
+    }
 }
 
 KMPLAYER_NO_EXPORT ByteArrayImpl &ByteArrayImpl::operator = (const char *b) {
@@ -622,6 +628,11 @@ String GMimeType::findByContent (const char * data, int size) {
 
 //-----------------------------------------------------------------------------
 
+KMPLAYER_NO_CDTOR_EXPORT
+GLibTextStream::GLibTextStream (const String *buffer)
+    : m_gstring (NULL), m_utf8_str (NULL), m_iter ((const char *) *buffer) {
+}
+
 GLibTextStream & GLibTextStream::operator >> (Char & ch) {
     if (m_gstring) {
         m_utf8_str = g_string_free (m_gstring, false);
@@ -649,6 +660,15 @@ GLibTextStream & GLibTextStream::operator = (const GLibTextStream & s) {
 }
 #endif
 
+KMPLAYER_NO_EXPORT String GLibTextStream::release () {
+    GLibString str;
+    if (m_gstring) {
+        str.takeUtf8 (g_string_free (m_gstring, false));
+        m_gstring = 0L;
+    }
+    return str;
+}
+
 String GLibTextStream::readLine () {
     String str;
     Char ch;
@@ -658,7 +678,7 @@ String GLibTextStream::readLine () {
             break;
         str += ch;
     }
-    gchar * iter = m_iter;
+    const gchar *iter = m_iter;
     while (!atEnd ()) { // FIXME: current is skipping emty lines as well
         *this >> ch;
         if (ch != '\r' && ch != '\n') {
