@@ -212,7 +212,7 @@ class ByteArrayImpl {
     bool data_owner;
 public:
     ByteArrayImpl ();
-    ByteArrayImpl (unsigned sz);
+    //ByteArrayImpl (unsigned sz);
     ByteArrayImpl (const ByteArrayImpl & other);
     ByteArrayImpl (const char * data, unsigned size);
     ~ByteArrayImpl ();
@@ -357,18 +357,18 @@ typedef GnomeVFSFile File;
 class GLibTextStream {
     GString * m_gstring;
     gchar * m_utf8_str;
-    gchar * m_iter;
+    const gchar * m_iter;
 public:
     GLibTextStream ();
-    GLibTextStream (const String & init);
-    GLibTextStream (ByteArray & init);
+    GLibTextStream (const String *buffer); // for reading from buffer only
+    GLibTextStream (const ByteArray *buffer); // for reading from buffer only
     ~GLibTextStream ();
     GLibTextStream & operator << (const String & str);
     GLibTextStream & operator << (const char * str);
     GLibTextStream & operator << (const Char & ch);
     GLibTextStream & operator << (int i);
     GLibTextStream & operator >> (Char & ch);
-    GLibTextStream & readRawBytes (char * b, unsigned length);
+    //GLibTextStream & readRawBytes (char * b, unsigned length);
     bool atEnd () const;
     bool isEmpty () const;
     const gchar *at () const;
@@ -923,11 +923,11 @@ KMPLAYER_NO_EXPORT inline Log errorLog () {
 KMPLAYER_NO_CDTOR_EXPORT inline ByteArrayImpl::ByteArrayImpl ()
  : m_data (0L), m_size (0), m_capacity (0), data_owner (true) {}
 
-KMPLAYER_NO_CDTOR_EXPORT inline ByteArrayImpl::ByteArrayImpl (unsigned sz)
- : m_data ((char *) malloc (sz)),
+/*KMPLAYER_NO_CDTOR_EXPORT inline ByteArrayImpl::ByteArrayImpl (unsigned sz)
+ : m_data ((char *) malloc (sz + 1)),
    m_size (sz),
    m_capacity (sz),
-   data_owner (true) {}
+   data_owner (true) { m_data[sz] = 0; }*/
 
 inline ByteArrayImpl::ByteArrayImpl (const char * d, unsigned sz)
  : m_data ((char *)d), m_size (sz), m_capacity (sz), data_owner (false) {}
@@ -1100,16 +1100,10 @@ KMPLAYER_NO_CDTOR_EXPORT inline GLibTextStream::GLibTextStream ()
     : m_gstring (g_string_sized_new (128)), m_utf8_str (0L), m_iter (0L) {}
 
 KMPLAYER_NO_CDTOR_EXPORT
-inline GLibTextStream::GLibTextStream (const String & init)
-    : m_gstring (g_string_new ((const char *) init)),
-      m_utf8_str (0L),
-      m_iter (0L) {}
-
-KMPLAYER_NO_CDTOR_EXPORT
-inline GLibTextStream::GLibTextStream (ByteArray & init)
-    : m_gstring (g_string_new_len (init.data (), init.size ())),
-      m_utf8_str (0L),
-      m_iter (0L) {}
+inline GLibTextStream::GLibTextStream (const ByteArray *buffer)
+    : m_gstring (NULL),
+      m_utf8_str (NULL),
+      m_iter (buffer->size () ? buffer->data () : NULL) {}
 
 KMPLAYER_NO_CDTOR_EXPORT inline GLibTextStream::~GLibTextStream () {
     if (m_gstring)
@@ -1118,15 +1112,6 @@ KMPLAYER_NO_CDTOR_EXPORT inline GLibTextStream::~GLibTextStream () {
         g_free (m_utf8_str);
 }
 
-KMPLAYER_NO_EXPORT inline String GLibTextStream::release () {
-    GLibString str;
-    if (m_gstring) {
-        str.takeUtf8 (g_string_free (m_gstring, false));
-        m_gstring = 0L;
-    }
-    return str;
-}
-
 KMPLAYER_NO_EXPORT inline GLibTextStream & GLibTextStream::operator << (int i) {
     return *this << String::number (i);
 }
@@ -1147,12 +1132,12 @@ KMPLAYER_NO_EXPORT inline GLibTextStream & GLibTextStream::operator << (const Ch
     return *this;
 }
 
-KMPLAYER_NO_EXPORT inline
+/*KMPLAYER_NO_EXPORT inline
 GLibTextStream & GLibTextStream::readRawBytes (char * b, unsigned len) {
     if (m_gstring)
         g_string_append_len (m_gstring, b, len);
     return *this;
-}
+}*/
 
 KMPLAYER_NO_EXPORT inline bool GLibTextStream::atEnd () const {
     return (m_iter && !m_iter[0]) || (!m_gstring && !m_iter);
